@@ -29,11 +29,13 @@ def migrate():
     # atlas
     atlas_host = 'https://aipanda181.cern.ch:443/idds'  # noqa F841
 
-    cm1 = ClientManager(host=dev_host)
+    cm1 = ClientManager(host=doma_host)
     # reqs = cm1.get_requests(request_id=290)
     old_request_id = 72533
-    for old_request_id in [148]:
+    # for old_request_id in [152]:
     # for old_request_id in [60]:    # noqa E115
+    # for old_request_id in [200]:    # noqa E115
+    for old_request_id in [183]:    # noqa E115  # doma 183
         reqs = cm1.get_requests(request_id=old_request_id, with_metadata=True)
 
         cm2 = ClientManager(host=dev_host)
